summaryrefslogtreecommitdiffstats
path: root/style
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 20:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 20:59:01 -0600
commit37ecc2870891c51e8f49161e78697c14a7cd4af5 (patch)
tree39c4c6fd912eb47a658d6288541ebd8b60ab98f2 /style
parentb0b88ce583cb7d3e0480a784fadf39327a875a6e (diff)
downloadtde-style-qtcurve-37ecc2870891c51e8f49161e78697c14a7cd4af5.tar.gz
tde-style-qtcurve-37ecc2870891c51e8f49161e78697c14a7cd4af5.zip
Rename kiobuffer and KHTML
Diffstat (limited to 'style')
-rw-r--r--style/qtcurve.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/style/qtcurve.cpp b/style/qtcurve.cpp
index e636293..4ba1dfe 100644
--- a/style/qtcurve.cpp
+++ b/style/qtcurve.cpp
@@ -48,11 +48,11 @@
*/
/*
-KHTML
+TDEHTML
-----
Srollbars:
-For some reason Scrollbars in KHTML seem to lose the bottom/left pixels. As if KHTML expects
+For some reason Scrollbars in TDEHTML seem to lose the bottom/left pixels. As if TDEHTML expects
the scrollbar to be 1 pixel smaller/thinner than it actually is. To 'fix' this, the pixelMetric
function will return 1 scrollbar with 1 greater than standard for form widgets, or where widget==0L
@@ -451,7 +451,7 @@ static bool isKhtmlFormWidget(const TQWidget *widget)
// Copied from Keramik...
//Form widgets are in the KHTMLView, but that has 2 further inner levels
//of widgets - TQClipperWidget, and outside of that, TQViewportWidget
TQWidget *potentialClipPort(widget ? widget->parentWidget() : 0L);
@@ -464,10 +464,10 @@ static bool isKhtmlFormWidget(const TQWidget *widget)
qstrcmp(potentialViewPort->name(), "qt_viewport"))
return false;
- TQWidget *potentialKHTML(potentialViewPort->parentWidget());
+ TQWidget *potentialTDEHTML(potentialViewPort->parentWidget());
- if (!potentialKHTML || potentialKHTML->isTopLevel() ||
- qstrcmp(potentialKHTML->className(), "KHTMLView"))
+ if (!potentialTDEHTML || potentialTDEHTML->isTopLevel() ||
+ qstrcmp(potentialTDEHTML->className(), "TDEHTMLView"))
return false;
return true;
@@ -2833,7 +2833,7 @@ void QtCurveStyle::drawBorder(const TQColor &bgnd, TQPainter *p, const TQRect &r
p->setPen(border);
if(itsFormMode)
{
// If we're itsFormMode (KHTML) then we need to draw the aa borders using pixmaps
// - so we need to draw 2 pixels away from each corner (so that the alpha
// blend lets through the background color...
p->drawLine(r.x()+2, r.y(), r.x()+r.width()-3, r.y());
@@ -2865,7 +2865,7 @@ void QtCurveStyle::drawBorder(const TQColor &bgnd, TQPainter *p, const TQRect &r
}
else
{
// If we're not itsFormMode (ie. not KHTML) then we can just draw 1 pixel in - as
// we can overwrite with the alpha colour.
p->drawLine(r.x()+1, r.y(), r.x()+r.width()-2, r.y());
p->drawLine(r.x()+1, r.y()+r.height()-1, r.x()+r.width()-2, r.y()+r.height()-1);
@@ -6178,7 +6178,7 @@ void QtCurveStyle::drawComplexControl(ComplexControl control, TQPainter *p, cons
{
bool enable=!atMax;
// See KHTML note at top of file
if(itsFormMode && SCROLLBAR_NEXT!=opts.scrollbarType) {
if(horiz) {
addline.addCoords(0, 0, -1, 0);
@@ -6866,7 +6866,7 @@ int QtCurveStyle::pixelMetric(PixelMetric metric, const TQStyleControlElementDat
case PM_SliderLength:
return SLIDER_TRIANGULAR==opts.sliderStyle ? 11 : (SLIDER_SIZE+(ROTATED_SLIDER ? -2 : 6));
case PM_ScrollBarExtent:
// See KHTML note at top of file
return opts.sliderWidth+
(APP_KPRESENTER==itsThemedApp ||
((APP_KONQUEROR==itsThemedApp || APP_KONTACT==itsThemedApp) && (!widget || isFormWidget(widget)))
@@ -8781,7 +8781,7 @@ void QtCurveStyle::adjustScrollbarRects(bool &itsFormMode,
if(itsFormMode)
{
// See KHTML note at top of file
if(horiz)
{
subline.addCoords(0, 0, 0, -1);
@@ -451,7 +451,7 @@ static bool isKhtmlFormWidget(const TQWidget *widget)
// Copied from Keramik...
- //Form widgets are in the KHTMLView, but that has 2 further inner levels
+ //Form widgets are in the TDEHTMLView, but that has 2 further inner levels
//of widgets - TQClipperWidget, and outside of that, TQViewportWidget
TQWidget *potentialClipPort(widget ? widget->parentWidget() : 0L);
@@ -2833,7 +2833,7 @@ void QtCurveStyle::drawBorder(const TQColor &bgnd, TQPainter *p, const TQRect &r
if(itsFormMode)
{
- // If we're itsFormMode (KHTML) then we need to draw the aa borders using pixmaps
+ // If we're itsFormMode (TDEHTML) then we need to draw the aa borders using pixmaps
// - so we need to draw 2 pixels away from each corner (so that the alpha
// blend lets through the background color...
@@ -2865,7 +2865,7 @@ void QtCurveStyle::drawBorder(const TQColor &bgnd, TQPainter *p, const TQRect &r
else
{
- // If we're not itsFormMode (ie. not KHTML) then we can just draw 1 pixel in - as
+ // If we're not itsFormMode (ie. not TDEHTML) then we can just draw 1 pixel in - as
// we can overwrite with the alpha colour.
p->drawLine(r.x()+1, r.y(), r.x()+r.width()-2, r.y());
@@ -6178,7 +6178,7 @@ void QtCurveStyle::drawComplexControl(ComplexControl control, TQPainter *p, cons
{
bool enable=!atMax;
- // See KHTML note at top of file
+ // See TDEHTML note at top of file
if(itsFormMode && SCROLLBAR_NEXT!=opts.scrollbarType) {
if(horiz) {
@@ -6866,7 +6866,7 @@ int QtCurveStyle::pixelMetric(PixelMetric metric, const TQStyleControlElementDat
return SLIDER_TRIANGULAR==opts.sliderStyle ? 11 : (SLIDER_SIZE+(ROTATED_SLIDER ? -2 : 6));
case PM_ScrollBarExtent:
- // See KHTML note at top of file
+ // See TDEHTML note at top of file
return opts.sliderWidth+
(APP_KPRESENTER==itsThemedApp ||
@@ -8781,7 +8781,7 @@ void QtCurveStyle::adjustScrollbarRects(bool &itsFormMode,
if(itsFormMode)
{
- // See KHTML note at top of file
+ // See TDEHTML note at top of file
if(horiz)
{